==> alps-2.1.1-r6176-src-with-boost.tar.gz: alps-2.1.1-r6176-src-with-boost/alps/test/ngs/params/ordering.cpp <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *                                                                                 *
 * ALPS Project: Algorithms and Libraries for Physics Simulations                  *
 *                                                                                 *
 * ALPS Libraries                                                                  *
 *                                                                                 *
 * Copyright (C) 2010 - 2011 by Lukas Gamper <gamperl@gmail.com>                   *
 *                              Matthias Troyer <troyer@comp-phys.org>             *
 *                                                                                 *
 * This software is part of the ALPS libraries, published under the ALPS           *
 * Library License; you can use, redistribute it and/or modify it under            *
 * the terms of the license, either version 1 or (at your option) any later        *
 * version.                                                                        *
 *                                                                                 *
 * You should have received a copy of the ALPS Library License along with          *
 * the ALPS Libraries; see the file LICENSE.txt. If not, the license is also       *
 * available from http://alps.comp-phys.org/.                                      *
 *                                                                                 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,        *
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT       *
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE       *
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,     *
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER     *
 * DEALINGS IN THE SOFTWARE.                                                       *
 *                                                                                 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#include <alps/ngs/hdf5.hpp>
#include <alps/ngs/params.hpp>

int main() {
    using alps::make_pvp;
    {
        alps::params parms;
        parms["a"] = 6;
        parms["x"] = 2;
        parms["b"] = 3;
        parms["w"] = 1;
        
        for (alps::params::const_iterator it = parms.begin(); it != parms.end(); ++it)
            std::cout << it->first << " " << it->second << std::endl;

        alps::hdf5::archive oar("test.h5", "w");
        oar
            << make_pvp("/parameters", parms)
        ;
    }
    std::cout << "= = = = =" << std::endl;
    {
        alps::params parms;
        alps::hdf5::archive iar("test.h5", "r");
        iar >> make_pvp("/parameters", parms);

        alps::params::const_iterator it = parms.begin();
        assert((it++)->first == "a");
        assert((it++)->first == "x");
        assert((it++)->first == "b");
        assert((it++)->first == "w");
    }
}

==> alps-2.3.0-src-with-boost.tar.gz: alps-2.3.0-src-with-boost/alps/test/ngs/params/ordering.cpp <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *                                                                                 *
 * ALPS Project: Algorithms and Libraries for Physics Simulations                  *
 *                                                                                 *
 * ALPS Libraries                                                                  *
 *                                                                                 *
 * Copyright (C) 2010 - 2011 by Lukas Gamper <gamperl@gmail.com>                   *
 *                              Matthias Troyer <troyer@comp-phys.org>             *
 *                                                                                 *
 * This software is part of the ALPS libraries, published under the ALPS           *
 * Library License; you can use, redistribute it and/or modify it under            *
 * the terms of the license, either version 1 or (at your option) any later        *
 * version.                                                                        *
 *                                                                                 *
 * You should have received a copy of the ALPS Library License along with          *
 * the ALPS Libraries; see the file LICENSE.txt. If not, the license is also       *
 * available from http://alps.comp-phys.org/.                                      *
 *                                                                                 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR     *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,        *
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT       *
 * SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE       *
 * FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,     *
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER     *
 * DEALINGS IN THE SOFTWARE.                                                       *
 *                                                                                 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#include <alps/hdf5/archive.hpp>
#include <alps/ngs/params.hpp>

int main() {
    std::string const filename = "odering";
    if (boost::filesystem::exists(boost::filesystem::path(filename)))
        boost::filesystem::remove(boost::filesystem::path(filename));
    {
        alps::params parms;
        parms["a"] = 6;
        parms["x"] = 2;
        parms["b"] = 3;
        parms["w"] = 1;
        
        for (alps::params::const_iterator it = parms.begin(); it != parms.end(); ++it)
            std::cout << it->first << " " << it->second << std::endl;

        alps::hdf5::archive oar(filename, "w");
        oar["/parameters"] << parms;
    }
    std::cout << "= = = = =" << std::endl;
    {
        alps::params parms;
        alps::hdf5::archive iar(filename, "r");
        iar["/parameters"] >> parms;

        alps::params::const_iterator it = parms.begin();
        assert((it++)->first == "a");
        assert((it++)->first == "x");
        assert((it++)->first == "b");
        assert((it++)->first == "w");
    }
    boost::filesystem::remove(boost::filesystem::path(filename));
    return 0;
}
